<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>EditText</name>
    <message>
        <location filename="../EditText.js" line="+61"/>
        <source>Choose text</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wskazać tekst</translation>
    </message>
    <message>
        <location filename="../EditTextInit.js" line="+2"/>
        <source>Edit Te&amp;xt</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Edytuj &amp;tekst</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Edit text</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Modyfikuj tekst</translatorcomment>
        <translation>Modyfikuje tekst</translation>
    </message>
</context>
</TS>
